# listgits
Python command line program for listing all git repositories under a folder root

Usage:

```
python listgits
```

Options :

* --h: Show the possible options
* --s: Short form, not showing non-git folders
* --l: Show only local repos, which do not have any remotes (includes --s)
* --r: Show only repos that have remotes (includes --s)


